"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import gcp.gcp_compute_route_pb2
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GoogleComputeRoute(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMPUTE_ROUTE_FIELD_NUMBER: builtins.int
    @property
    def compute_route(self) -> gcp.gcp_compute_route_pb2.ComputeRoute: ...
    def __init__(
        self,
        *,
        compute_route: gcp.gcp_compute_route_pb2.ComputeRoute | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["compute_route", b"compute_route"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["compute_route", b"compute_route"]) -> None: ...

global___GoogleComputeRoute = GoogleComputeRoute



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import gcp.gcp_redis_pb2
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GoogleRedis(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REDIS_INSTANCE_FIELD_NUMBER: builtins.int
    @property
    def redis_instance(self) -> gcp.gcp_redis_pb2.RedisInstance: ...
    def __init__(
        self,
        *,
        redis_instance: gcp.gcp_redis_pb2.RedisInstance | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["redis_instance", b"redis_instance"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["redis_instance", b"redis_instance"]) -> None: ...

global___GoogleRedis = GoogleRedis



import json
import core.sdk.helper as Helper
from models.shared.shared_pb2 import RunnerInput

class RunnerInputService:
    '''
    Provides access to the runner input data
    '''
    def fetch_runner_input(request_id: str):
        #TODO: temporary this class loads the runner input from a local source,
        # this will be refactored to get data from an endpoint using the request_id

        if not request_id:
            return None

        runner_input: RunnerInput = None
        with open('D:\\poc\\runner_package_test\\runner_input_tython_complete.json', 'r') as file:
            raw_input = json.load(file)
            raw_snake_case_input = Helper.snake_case_json(raw_input)
            raw_item1 = raw_snake_case_input[0]['item1']
            for root_node in raw_item1['graph']['root_nodes']:
                root_node['node']['resource']['data']['value'] = bytes(root_node['node']['resource']['data']['value'])
            Helper.remove_attributes(raw_item1, "has_")
            runner_input = RunnerInput(**raw_item1)
        
        return runner_input



import os
from setuptools import setup, find_packages

package_data = {}

for package in find_packages():
    package_data[package] = ["*.pyi"]

version = os.environ.get('PYPIVERSION', '').split('/')[-1]

setup_args = dict(
    name = "oak9_tython",
    version=version,
    packages=find_packages(),
    package_data=package_data,
    author=["Claudio Balbin <cbalbin@oak9.io>","Brandon Nicoll <bnicoll@oak9.io>" ],
    description = "",
    readme = "README.md",
    classifiers = [
    "Programming Language :: Python :: 3",
    "License :: OSI Approved :: Apache Software License",
    "Operating System :: OS Independent",
    ],
    project_urls={
        "Homepage": "https://github.com/oak9io/tython",
        "Bug Tracker": "https://github.com/oak9io/tython/issues",
    },
    python_requires=">=3.11",
    long_description="oak9 Tython Python framework",
    long_description_content_type="text/markdown"
)

if __name__ == '__main__':
    setup(**setup_args)
